# [0.4.10](https://github.com/seriaati/hakushin-py/compare/v0.4.9..v0.4.10) - 2025-03-01

## Bug Fixes

- Fix incorrect field name - ([696052c](https://github.com/seriaati/hakushin-py/commit/696052c86b1784abe9179111e06c1b93c24eb285))

